==> haskell-parser-combinators-1.0.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parser-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parser-combinators
version: 1.0.2
id: parser-combinators-1.0.2-IyNQpKDV9bJE8mJzaajfJ
key: parser-combinators-1.0.2-IyNQpKDV9bJE8mJzaajfJ
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
        Alex Washburn <github@recursion.ninja>
homepage: https://github.com/mrkkrp/parser-combinators
synopsis: Lightweight package providing commonly useful parser combinators
description:
    Lightweight package providing commonly useful parser combinators.
category: Parsing
abi: fb53ccef00fec85a9b18a933cdbdabad
exposed: True
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.Expr Control.Monad.Combinators.NonEmpty
import-dirs: /usr/lib/ghc-8.6.5/site-local/parser-combinators-1.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/parser-combinators-1.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/parser-combinators-1.0.2
hs-libraries: HSparser-combinators-1.0.2-IyNQpKDV9bJE8mJzaajfJ
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock
haddock-html: /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parser-combinators-1.0.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parser-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parser-combinators
version: 1.0.3
id: parser-combinators-1.0.3-1G8nppuMEiR2Ao7u4R9lsu
key: parser-combinators-1.0.3-1G8nppuMEiR2Ao7u4R9lsu
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
        Alex Washburn <github@recursion.ninja>
homepage: https://github.com/mrkkrp/parser-combinators
synopsis: Lightweight package providing commonly useful parser combinators
description:
    Lightweight package providing commonly useful parser combinators.
category: Parsing
abi: 4e0f45699a65a5ddeff2660596fd36dc
exposed: True
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.Expr Control.Monad.Combinators.NonEmpty
import-dirs: /usr/lib/ghc-8.6.5/site-local/parser-combinators-1.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/parser-combinators-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/parser-combinators-1.0.3
hs-libraries: HSparser-combinators-1.0.3-1G8nppuMEiR2Ao7u4R9lsu
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock
haddock-html: /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
